@@ -498,41 +498,46 @@ void nvUvmInterfaceMemoryCpuUnMap(uvmGpuAddressSpaceHandle vaSpace,
 /*******************************************************************************
     nvUvmInterfaceChannelAllocate
 
-    This function will allocate a channel
+    This function will allocate a channel bound to a copy engine
 
-    UvmGpuChannelPointers: this structure will be filled out with channel
-    get/put. The errorNotifier is filled out when the channel hits an RC error.
+    allocParams must contain an engineIndex as channels need to be bound to an
+    engine type at allocation time. The possible values are [0,
+    UVM_COPY_ENGINE_COUNT_MAX), but notably only the copy engines that have
+    UvmGpuCopyEngineCaps::supported set to true can be allocated. This struct
+    also contains information relative to GPFIFO and GPPut.
+
+    channel is filled with the address of the corresponding channel handle.
+
+    channelInfo is filled out with channel get/put. The errorNotifier is filled
+    out when the channel hits an RC error. On Volta+ devices, it also computes
+    the work submission token and the work submission offset to be used in the
+    Host channel submission doorbell.
+
+    Arguments:
+        vaSpace[IN]      - VA space linked to a client and a device under which
+                           the channel will be allocated
+        allocParams[IN]  - structure with allocation settings
+        channel[OUT]     - pointer to the new channel handle
+        channelInfo[OUT] - structure filled with channel information
 
     Error codes:
       NV_ERR_GENERIC
       NV_ERR_NO_MEMORY
 */
-
-NV_STATUS nvUvmInterfaceChannelAllocate(uvmGpuAddressSpaceHandle  vaSpace,
-                                        uvmGpuChannelHandle *channel,
+NV_STATUS nvUvmInterfaceChannelAllocate(uvmGpuAddressSpaceHandle vaSpace,
                                         const UvmGpuChannelAllocParams *allocParams,
-                                        UvmGpuChannelPointers * pointers);
-
-void nvUvmInterfaceChannelDestroy(uvmGpuChannelHandle channel);
+                                        uvmGpuChannelHandle *channel,
+                                        UvmGpuChannelInfo *channelInfo);
 
 /*******************************************************************************
-    nvUvmInterfaceCopyEngineAlloc
+    nvUvmInterfaceChannelDestroy
 
-    copyEngineIndex corresponds to the indexing of the
-    UvmGpuCaps::copyEngineCaps array. The possible values are
-    [0, UVM_COPY_ENGINE_COUNT_MAX), but notably only the copy engines that have
-    UvmGpuCopyEngineCaps::supported set to true can be allocated. On Volta+
-    devices, this function computes the work submission token and the work
-    submission offset to be used in the Host channel submission doorbell.
+    This function destroys a given channel
 
-    Error codes:
-      NV_ERR_GENERIC
-      NV_ERR_NO_MEMORY
+    Arguments:
+        channel[IN]     - channel handle
 */
-NV_STATUS nvUvmInterfaceCopyEngineAlloc(uvmGpuChannelHandle channel,
-                                        unsigned copyEngineIndex,
-                                        uvmGpuCopyEngineHandle *copyEngine,
-                                        UvmGpuChannelPointers *pointers);
+void nvUvmInterfaceChannelDestroy(uvmGpuChannelHandle channel);
 
 /*******************************************************************************
     nvUvmInterfaceQueryCaps
